@@ -8,15 +8,25 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 set -u
 
-label="grib_ecc-1224-test"
+label="grib2_chemicals_aerosols_test"
 temp=temp.$label
+temp1=temp.$label.1
 sample2=$ECCODES_SAMPLES_PATH/GRIB2.tmpl
 
 latest=`${tools_dir}/grib_get -p tablesVersionLatest $sample2`
 
+# Check latest chemical/aerosol code tables
+# -----------------------------------------
+${tools_dir}/grib_set -s tablesVersion=$latest,paramId=217224  $sample2 $temp
+grib_check_key_equals $temp constituentTypeName "Aceto nitrile CH3CN"
+
+${tools_dir}/grib_set -s tablesVersion=$latest,paramId=210249  $sample2 $temp
+grib_check_key_equals $temp aerosolTypeName "Ammonium dry"
+
+
 # =============================
 # Deterministic instantaneous
 # =============================
@@ -97,6 +107,39 @@ ${tools_dir}/grib_set -s is_aerosol=1 $tempSample $temp
 grib_check_key_equals $temp productDefinitionTemplateNumber '45'
 grib_check_key_equals $temp aerosolType,typeOfSizeInterval '0 0'
 
+# Keys firstSize and secondSize
+${tools_dir}/grib_set -s paramId=210072 $tempSample $temp
+${tools_dir}/grib_ls -p firstSize,secondSize $temp
 
-rm -f $tempSample
-rm -f $temp
+# ECC-1303: Setting localDefinitionNumber=1 on chemical source/sink
+# ------------------------------------------------------------------
+${tools_dir}/grib_set -s paramId=228104,setLocalDefinition=1,localDefinitionNumber=1 $sample2 $temp
+grib_check_key_equals $temp paramId,productDefinitionTemplateNumber,is_chemical_srcsink,localUsePresent '228104 76 1 1'
+
+${tools_dir}/grib_set -s stepType=accum,paramId=228104 $sample2 $temp
+grib_check_key_equals $temp shortName,productDefinitionTemplateNumber,is_chemical_srcsink 'e_WLCH4 78 1'
+${tools_dir}/grib_set -s setLocalDefinition=1,localDefinitionNumber=1 $temp $temp1
+${tools_dir}/grib_compare -b totalLength,numberOfSection $temp $temp1
+grib_check_key_equals $temp1 localUsePresent 1
+
+# Check local ECMWF chemicals/aerosols
+# ------------------------------------
+${tools_dir}/grib_set -s paramId=217232 $sample2 $temp
+${tools_dir}/grib_dump -O -p constituentType $temp > $temp1
+grep -q "Biomass burning volatile organic compounds .*grib2/tables/local/ecmf/1/4.230.table" $temp1
+
+${tools_dir}/grib_set -s paramId=219231 $sample2 $temp
+${tools_dir}/grib_dump -O -p constituentType $temp > $temp1
+grep -q "Anthropogenic volatile organic compounds .*grib2/tables/local/ecmf/1/4.230.table" $temp1
+
+${tools_dir}/grib_set -s paramId=211248 $sample2 $temp
+${tools_dir}/grib_dump -O -p aerosolType $temp > $temp1
+grep -q "Nitrate Coarse Mode .*grib2/tables/local/ecmf/1/4.233.table" $temp1
+
+${tools_dir}/grib_set -s paramId=215189 $sample2 $temp
+${tools_dir}/grib_dump -O -p aerosolType $temp > $temp1
+grep -q "Nitrate Fine Mode .*grib2/tables/local/ecmf/1/4.233.table" $temp1
+grib_check_key_equals $temp aerosolTypeName "Nitrate Fine Mode"
+
+# Clean up
+rm -f $tempSample $temp $temp1
